
# Slot: default_range


default slot range to be used if range element is omitted from a slot definition

URI: [linkml:default_range](https://w3id.org/linkml/default_range)


## Domain and Range

schema_definition &#8594;  <sub>0..1</sub> type_definition

## Parents


## Children


## Used by

 * schema_definition
